/*
** Module   : ComboBoxConfig.java
** Abstract : stores combo box specific state
**
** Copyright (c) 2005-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------Description-----------------
** 001 EVL 20050714   @21692 Creation based on general concept. Necessary
**                           modification to get compiled.
** 002 EVL 20050723   @21804 Adding one more attribute: innerLines.
** 003 SIY 20050831   @22491 Refactoring (see @@22394-22409) 
** 004 NVS 20051116   @23343 Class access changed to public. 
** 005 SIY 20051129   @23561 Moved item list member to parent class.
** 006 SIY 20060209   @24485 Major refactoring.
** 007 SIY 20060209   @24496 Fixed trap in setMaximumRowCount.
** 008 NVS 20060313   @25040 Moved format, setFormat() and getFormat() to
**                           the superclass, ControlSetConfig, so that
**                           format methods are available in SelectionList
**                           as well.
** 009 GES 20060803   @28397 Made externalizable for better performance.
**                           Many code standard cleanups.
** 010 EVL 20060809   @28497 Fix for DropDown line mismatch.
** 011 SIY 20061213   @31674 Encapsulated fields.
** 012 SIY 20100619          Switching to own implementation of character UI.
** 013 SIY 20100804          Changes in imports, some refactorings.
** 014 SIY 20111101          Moved from CHUI package. Minor 
**                           cleanups/refactorings in preparation to GUI client.
** 015 SIY 20111202          Updated imports.
** 016 CA  20140926          Added shared widget configuration support, to allow GUI/ChUI
**                           concrete implementation for the same widget ID.  Refactored the
**                           widget configuration classes: all fields were made public; these
**                           classes need to be as dumb as possible, all logic related to
**                           setting/getting a certain field should be at the widget or at the
**                           caller. Refs #2254
** 017 SVL 20141102          Added MAX-CHARS attribute.
*/

package com.goldencode.p2j.ui;

import java.io.*;

/**
 * Stores combo-box specific state.
 */
public class ComboBoxConfig
extends ControlSetConfig
{
   /** The Progress AUTO-ZAP attribute. */
   public boolean autoZap = true;

   /** The amount of the item lines in the list */
   public int innerLines = 0;

   /** MAX-CHARS attribute. */
   public int maxChars = 255;
   
   /**
    * Default constructor (only used in de-serialization).
    */
   public ComboBoxConfig()
   {
   }

   /**
    * Create a new config and associate it with the given widget.
    * 
    * @param    id
    *           The ID of the widget to which this configuration belongs.
    */
   protected ComboBoxConfig(int id)
   {
      super(id);
   }

   /**
    * Create a new config and associate it with the given widget.
    * 
    * @param    id
    *           The ID of the widget to which this configuration belongs.
    */
   protected ComboBoxConfig(WidgetId id)
   {
      super(id);
   }

   /**
    * Set new values from the provided configuration instance.
    * 
    * @param    config
    *           The instance from which to take values.
    */
   @Override
   public void applyConfig(WidgetConfig config)
   {
      super.applyConfig(config);
      
      ComboBoxConfig cfg = (ComboBoxConfig) config;
      
      autoZap = cfg.autoZap;
      innerLines = cfg.innerLines;
      maxChars = cfg.maxChars;
   }

   /**
    * Replacement for the default object reading method. The latest
    * state is read from the input source.  The parent's state is
    * read first.
    * 
    * @param    in
    *           The input source from which fields will be restored.
    *
    * @throws   IOException
    *           In case of I/O errors.
    * @throws   ClassNotFoundException
    *           If payload can't be instantiated.
    */
   @Override
   public void readExternal(ObjectInput in)
   throws IOException,
          ClassNotFoundException
   {
      super.readExternal(in);
      innerLines     = in.readInt();
      autoZap        = in.readBoolean();
      maxChars       = in.readInt();
   }

   /**
    * Replacement for the default object writing method. The latest
    * state is written to the output destination.  The parent's state is
    * written first.
    * 
    * @param    out
    *           The output destination to which fields will be saved.
    *
    * @throws   IOException
    *           In case of I/O errors.
    */
   @Override
   public void writeExternal(ObjectOutput out)
   throws IOException
   {
      super.writeExternal(out);
      out.writeInt(innerLines);
      out.writeBoolean(autoZap);
      out.writeInt(maxChars);
   }
}
